import os
import logging.config
import yaml

def setup_logging(
    default_path='../logging.yaml',
    default_level=logging.INFO,
    env_key='LOG_CFG'
):
    """Setup logging configuration

    """
    path = default_path
    value = os.getenv(env_key, None)
    if value:
        path = value
    if os.path.exists(path):
        with open(path, 'rt') as f:
            config = yaml.safe_load(f.read())
        logging.config.dictConfig(config)
    else:
        logging.basicConfig(level=default_level)


import logging
from .utils.exceptions import IncorrectParameters
__LOGGER__ = logging.getLogger(__name__)



class doohickey(object):
    
    __class_method = None

    def __init__(self):
        pass

    def __private_method(self):
        pass

    def _hidden_method(self):
        pass

    def method(self):
        pass

    @property
    def prop(self):
        return self.__prop
        
    @prop.setter
    def prop(self, value):
        self.__prop = value


from setuptools import setup, find_packages

def parse_requirements(requirement_file):
    with open(requirement_file) as f:
        return f.readlines()

version = dict()
with open("./doohickey/utils/version.py") as fp:
    exec(fp.read(), version)


setup(
    name='doohickey',
    version=version['__version__'],
    packages=find_packages(exclude=['tests*']),
    license='MIT',
    description='A Python package that creates personal tools and frameworks I commonly use',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    install_requires=parse_requirements('./requirements.txt'),
    keywords=['carcass'],
    url='https://github.com/MSAdministrator/doohickey',
    author='MSAdministrator',
    author_email='rickardja@live.com',
    python_requires='>=2.6, !=3.0.*, !=3.1.*, !=3.2.*, <4'
)